@@ -26,6 +26,7 @@ from vivarium.processes.nonspatial_environment import (
 from vivarium.processes.swap_processes import SwapProcesses
 from vivarium.processes.remove import Remove
 from vivarium.processes.divide_condition import DivideCondition
+from vivarium.processes.mass_adaptor import MassToConcentration, MassToCount
 
 # import updaters, dividers, serializers
 from vivarium.core.registry import (
@@ -52,6 +53,8 @@ process_registry.register(
 process_registry.register(SwapProcesses.name, SwapProcesses)
 process_registry.register(Remove.name, Remove)
 process_registry.register(Clock.name, Clock)
+process_registry.register(MassToConcentration.name, MassToConcentration)
+process_registry.register(MassToCount.name, MassToCount)
 
 # register updaters
 updater_registry.register('accumulate', update_accumulate)
